InductiveNodePieceGNN
=====================

.. currentmodule:: pykeen.models

.. autoclass:: InductiveNodePieceGNN
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~InductiveNodePieceGNN.reset_parameters_

   .. rubric:: Methods Documentation

   .. automethod:: reset_parameters_
